class pe_cert_auth::proxy {
  ## Configure haproxy for our puppet masters.
  class { '::haproxy': }

  ## HA puppet masters
  haproxy::listen { 'puppet00':
    ipaddress        => '*',
    ports            => '8140',
    collect_exported => false,
  }
  haproxy::balancermember { "puppetmaster $::primary_master_name":
    listening_service => 'puppet00',
    ipaddresses       => "$::primary_master_address",
    ports             => '8140',
    options           => 'check',
  }
  create_resources(haproxy::balancermember, $::masters)

  ## HA activemq
  haproxy::listen { 'activemq00':
    ipaddress        => '*',
    ports            => '61613',
    collect_exported => false,
  }
  haproxy::balancermember { "activemq $::primary_master_name":
    listening_service => 'activemq00',
    ipaddresses       => "$::primary_master_name",
    ports             => '61613',
    options           => 'check',
  }
  create_resources(haproxy::balancermember, $::activemq_masters)

  file { '/etc/rsyslog.d/haproxy.conf':
    ensure  => file,
    content => 'local0.* -/var/log/haproxy.log',
    owner   => 'root',
    group   => 'root',
    mode    => '0600',
    notify  => Service['rsyslog'],
  }

  File_line {
    ensure => present,
    path   => '/etc/rsyslog.conf',
    notify => Service['rsyslog'],
  }

  file_line { 'modload_imudp':
    line   => '$ModLoad imudp',
    match  => 'ModLoad imudp',
  }
  file_line { 'modload_imtcp':
    line   => '$ModLoad imtcp',
    match  => 'ModLoad imtcp',
  }
  file_line { 'udpserverrun':
    line   => '$UDPServerRun 514',
    match  => 'UDPServerRun 514',
  }
  file_line { 'tcpserverrun':
    line   => '$InputTCPServerRun 514',
    match  => 'InputTCPServerRun 514',
  }
  service { 'rsyslog':
    ensure =>  running,
    enable => true,
  }

}
